==> hekate:hqed-m5_6.tar.gz: hqed-m5_6/C/StartScreen_ui.h <==
 /**
<<<<<<< StartScreen_ui.h
 *                                                                             *
 * @file StartScreen_ui.h                                                      *
 * Project name: HeKatE hqed                                                   *
 * $Id: StartScreen_ui.h,v 1.11 2008-03-31 10:23:05 kinio Exp $                *
 * Author: Krzysztof Kaczor                                                    *
 * Date: 14.01.2008                                                            *
 *                                                                             *
 * Implementation by Krzysztof Kaczor <kinio4444@gmail.com>                    *
 *                                                                             *
 * Copyright (C) 2006-9 by the HeKatE Project                                  *
 *                                                                             *
 * HQEd has been develped within the HeKatE Project,                           *
 * see http://hekate.ia.agh.edu.pl                                             *
 *                                                                             *
 * This file is part of HQEd.                                                  *
 *                                                                             *
 * HQEd is free software: you can redistribute it and/or modify                *
 * it under the terms of the GNU General Public License as published by        *
 * the Free Software Foundation, either version 3 of the License, or           *
 * (at your option) any later version.                                         *
 *                                                                             *
 * HQEd is distributed in the hope that it will be useful,                     *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 * GNU General Public License for more details.                                *
 *                                                                             *
 * You should have received a copy of the GNU General Public License           *
 * along with HQEd.  If not, see <http://www.gnu.org/licenses/>.               *
 *                                                                             *
 * Comment: Plik zawierajacy definicje klasy oblugujacej okno wspomagajace     *
 * tworzenie zawartosci komorki                                                *
 *                                                                             *
=======
 * \file	StartScreen_ui.h
 * \author	Krzysztof Kaczor kinio4444@gmail.com
 * \date 	14.01.2008 
 * \version	1.0
 * \brief	This file defines class arranges window creating content of cell.
 * \note This file is a part of HQEd. It has been develped within the HeKatE Project.
 * HQEd is a free software that you can redistribute and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License or 
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License with HQEd.
 * \note HQEd is distributed in hope that will be useful.
 * It has NO ANY WARRANTY, neither implied warranty of
 * MERCHANTABILITY nor FITNESS FOR A PARTICULAR PURPOSE. 
 * \note Copyright (C) 2006-9 by the HeKatE Project.
 * \see GNU General Public License for more details http://www.gnu.org/licenses/
 * \see HeKatE project http://hekate.ia.agh.edu.pl
>>>>>>> 1.10
 */

#ifndef StartScreenH
#define StartScreenH
// -----------------------------------------------------------------------------

#include "../ui_StartScreen.h"
// -----------------------------------------------------------------------------

class GLStartWidget;
// -----------------------------------------------------------------------------
/**
* \class 	StartScreen_ui
* \author	Krzysztof Kaczor kinio4444@gmail.com
* \date 	14.01.2008
* \brief 	This class arranges window creating content of cell.
*/
class StartScreen_ui : public QWidget, private Ui_StartScreen
{
    Q_OBJECT
    
    GLStartWidget* glScreen;	///< Pointer to OpenGl screen;

protected:

	/// \brief Function is triggered when key is pressed.
	///
	/// \param event Pointer to event object.
	/// \return No return value.
	void keyPressEvent(QKeyEvent* event);
     
public:

    /// \brief Constructor StartScreen_ui class.
	///
	/// \param parent Pointer to parent object.
     StartScreen_ui(QWidget *parent = 0);
	
	/// \breif Destructor About_ui class.
	~StartScreen_ui(void);
	
public slots:

	/// \brief Run application.
	///
	/// \return No return value.
	void runApplication(void);
};
// -----------------------------------------------------------------------------

extern StartScreen_ui* StartScreen;
// -----------------------------------------------------------------------------

#endif

==> hekate:hqed-m6_6.tar.gz: hqed-m6_6/C/StartScreen_ui.h <==
 /**
 * \file	StartScreen_ui.h
 * \author	Krzysztof Kaczor kinio4444@gmail.com
 * \date 	14.01.2008 
 * \version	1.0
 * \brief	This file defines class arranges window creating content of cell.
 * \note This file is a part of HQEd. It has been develped within the HeKatE Project.
 * HQEd is a free software that you can redistribute and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License or 
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License with HQEd.
 * \note HQEd is distributed in hope that will be useful.
 * It has NO ANY WARRANTY, neither implied warranty of
 * MERCHANTABILITY nor FITNESS FOR A PARTICULAR PURPOSE. 
 * \note Copyright (C) 2006-9 by the HeKatE Project.
 * \see GNU General Public License for more details http://www.gnu.org/licenses/
 * \see HeKatE project http://hekate.ia.agh.edu.pl
 */

#ifndef StartScreenH
#define StartScreenH
// -----------------------------------------------------------------------------

#include "../ui_StartScreen.h"
// -----------------------------------------------------------------------------

class GLStartWidget;
// -----------------------------------------------------------------------------
/**
* \class 	StartScreen_ui
* \author	Krzysztof Kaczor kinio4444@gmail.com
* \date 	14.01.2008
* \brief 	This class arranges window creating content of cell.
*/
class StartScreen_ui : public QWidget, private Ui_StartScreen
{
    Q_OBJECT
    
    GLStartWidget* glScreen;	///< Pointer to OpenGl screen;

protected:

	/// \brief Function is triggered when key is pressed.
	///
	/// \param event Pointer to event object.
	/// \return No return value.
	void keyPressEvent(QKeyEvent* event);
     
public:

    /// \brief Constructor StartScreen_ui class.
	///
	/// \param parent Pointer to parent object.
     StartScreen_ui(QWidget *parent = 0);
	
	/// \brief Destructor About_ui class.
	~StartScreen_ui(void);
	
public slots:

	/// \brief Run application.
	///
	/// \return No return value.
	void runApplication(void);
};
// -----------------------------------------------------------------------------

extern StartScreen_ui* StartScreen;
// -----------------------------------------------------------------------------

#endif
